// @ts-nocheck
import React, { useEffect, useRef } from 'react'

import api, { Transform } from '../store'

type PhantomProps = {
  id: string
}

const Phantom: React.FC<PhantomProps> = ({ id }) => {
  const ref = useRef<THREE.Mesh>(null)

  useEffect(() => {
    if (ref.current) {
      api.subscribe(
        (state: Transform | null) => {
          if (!state) {
            return
          }
          ref.current?.position.fromArray([
            state.position[0],
            state.position[1] + 1.25,
            state.position[2],
          ])
          ref.current?.rotation.fromArray(state.rotation)
        },
        (state) => state?.userTransforms?.[id],
      )
    }
  }, [ref.current])

  return (
    <mesh ref={ref}>
      <sphereBufferGeometry args={[1, 16, 16]} />
      <meshStandardMaterial color="hotpink" />
    </mesh>
  )
}

export default Phantom
